@@ -319,6 +319,7 @@ couchdb_session_get_database_info (CouchdbSession *session, const char *dbname,
 		}
 	}
 	g_object_unref (G_OBJECT (parser));
+	g_free (url);
 
 	return result;
 }
@@ -343,8 +344,14 @@ couchdb_session_get_database (CouchdbSession *session, const char *dbname, GErro
 	g_return_val_if_fail (dbname != NULL, NULL);
 
 	dbinfo = couchdb_session_get_database_info (session, dbname, error);
-	if (dbinfo != NULL)
-		return couchdb_database_new (session, dbname);
+	if (dbinfo != NULL) {
+		CouchdbDatabase *db;
+
+		db = couchdb_database_new (session, dbname);
+		couchdb_database_info_unref (dbinfo);
+
+		return db;
+	}
 
 	return NULL;
 }
@@ -550,9 +557,9 @@ couchdb_session_is_authentication_enabled (CouchdbSession *session)
 }
 
 static gboolean
-_session_authenticate(SoupSession *http_session, SoupMessage *msg,
-		      SoupAuth *auth, gboolean retrying,
-		      gpointer callback_data)
+_session_authenticate (SoupSession *http_session, SoupMessage *msg,
+		       SoupAuth *auth, gboolean retrying,
+		       gpointer callback_data)
 {
 	CouchdbSession *session;
 
