@@ -23,17 +23,16 @@
 #define __DBWATCH_H__
 
 #include <glib.h>
-#include "couchdb-session.h"
+#include "couchdb-database.h"
 #include "utils.h"
 
 typedef struct {
-	CouchdbSession *couchdb;
-	gchar *dbname;
+	CouchdbDatabase *database;
 	gint last_update_seq;
 	guint timeout_id;
 } DBWatch;
 
-DBWatch *dbwatch_new (CouchdbSession *couchdb, const gchar *dbname, gint update_seq);
+DBWatch *dbwatch_new (CouchdbDatabase *database, gint update_seq);
 void     dbwatch_free (DBWatch *watch);
 
 #endif /* __DBWATCH_H__ */
