@@ -34,7 +34,7 @@ main (int argc, char *argv[])
 
 	/* Initialize Couchdb */
 	couchdb =  argc > 1 ? couchdb_session_new (argv[1]) : couchdb_session_new (NULL);
-	g_printf ("Connecting to Couchdb at %s\n", couchdb_session_get_uri (couchdb));
+	g_print ("Connecting to Couchdb at %s\n", couchdb_session_get_uri (couchdb));
 	
 	if (!couchdb) {
 		g_print ("Could not create Couchdb object\n");
@@ -80,19 +80,14 @@ main (int argc, char *argv[])
 		g_assert (database != NULL);
 
 		error = NULL;
-		doclist = couchdb_database_list_documents (couchdb, &error);
+		doclist = couchdb_database_get_all_documents (database, &error);
 		if (doclist) {
 			GSList *sl_doc;
 
 			g_print ("\tDocuments:\n");
 			for (sl_doc = doclist; sl_doc != NULL; sl_doc = sl_doc->next) {
-				CouchdbDocumentInfo *doc_info = sl_doc->data;
-				CouchdbDocument *document;
+				CouchdbDocument *document = COUCHDB_DOCUMENT (sl_doc->data);
 
-				error = NULL;
-				document = couchdb_database_get_document (database,
-									  couchdb_document_info_get_docid (doc_info),
-									  &error);
 				if (document) {
 					char *json;
 
@@ -105,10 +100,6 @@ main (int argc, char *argv[])
 					g_free (json);
 
 					g_object_unref (G_OBJECT (document));
-				} else {
-					g_print ("\t\t%s\t(rev: %s)\n",
-						 couchdb_document_info_get_docid (doc_info),
-						 couchdb_document_info_get_revision (doc_info));
 				}
 			}
 
